/*
 * kbiff.h
 * Copyright (C) 1999-2004 Kurt Granroth <granroth@kde.org>
 *
 * This file contains the declaration of the main KBiff
 * widget.
 *
 * $Id$
 */
#ifndef KBIFF_H 
#define KBIFF_H 

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif 

#include <qlist.h>

#include "kbiffmonitor.h"
#include "setupdlg.h"

#include "kbiffurl.h"
#include <KApplication>

#include <qlabel.h>
#include <qtimer.h>

#include "status.h"


class Led;
class KBiff : public QLabel
{
    Q_OBJECT
public:
    KBiff(QWidget *parent_ = 0);
    virtual ~KBiff();

    bool isDocked() const;

    void processSetup(const KBiffSetup* setup, bool start);
    void readSessionConfig();

    void setMailboxList(const QList<KBiffMailbox*>& mailbox_list, unsigned int poll = 60);

public slots:
    void slotPlaySound(const QString&);
    void slotLaunchFetchClient(const QString&);
    void slotLaunchMailClient();

protected:
    void mousePressEvent(QMouseEvent *);

protected:
    void popupMenu();
    void reset();
    bool isRunning();
    bool isGIF8x(const QString & file);
    void executeCommand(const QString& command);
    void registerMe();
    QString getStatusText();

protected slots:
    void saveYourself();
    void invokeHelp();
    void displayPixmap();
    void haveNewMail(const int, const QString &);
    void haveNoNewMail();
    void dock();
    void setup();
    void checkMailNow();
    void readMailNow();
    void readPop3MailNow();
    void stop();
    void start();
    void invalidLogin(const QString& mailbox);
    void activateRequested(bool, const QPoint&);
    void notificationActivated(unsigned int);

private:
    bool findMailbox(const QString& url, QString& proxy);
    int newMailCount(const QString& url);

    QString getURLWithNewMail();
    QString getMailBoxWithNewMail();
    QString replaceCommandArgs(QString cmdStr);
    KMenu*  constructMenu(KMenu* m=NULL);
    void setupMenuItems(QList<QAction*> actions);

protected:
    bool myMUTEX;
    QList<KBiffMonitor*> monitorList;
    KBiffStatusList     statusList;
    QStringList         proxyList;

    // Capability
    QTimer  *statusTimer;
    
    // General settings
    QString profile;
    QString mailClient;

    // New mail
    bool    systemBeep;
    bool    runCommand;
    QString runCommandPath;
    bool    runResetCommand;
    QString runResetCommandPath;
    bool    playSound;
    QString playSoundPath;
    bool    notify;
    bool    dostatus;

    bool    docked;
    bool    sessions;
    bool    skipcheck;

    bool    isSecure;

    QString noMailIcon;
    QString newMailIcon;
    QString oldMailIcon;
    QString noConnIcon;
    QString stoppedIcon;

    KStatusNotifierItem *status;
    bool         statusChanged;

    Led *mled;
};

#endif // KBIFF_H 
