/*
 * kbiffurl.cpp
 * Copyright (C) 1999-2002 Kurt Granroth <granroth@kde.org>
 * Copyright (C) 1999 Bjorn Hansson <Bjorn.Hansson@signal.uu.se>
 *
 * This file contains the implementation of KBiffURL and
 *
 * $Id$
 */
#include <QRegExp>
#include "kbiffurl.h"

KBiffURL::KBiffURL()
	: KUrl()
{
}

KBiffURL::KBiffURL(const QString& _url)
  : KUrl(_url)
{
  /**
   * There exists no search part in the nntp spec; let's go around that
   */
  if (protocol() == "nntp")
  {
    QString urlStr(_url);
    urlStr.replace(0,4, "imap4");
    *this = KBiffURL(urlStr);
    setProtocol("nntp");
  }
}

/**
 * BNF description of the syntax (see RFC1738, HTTP syntax)
 * ; HTTP
 *
 * httpurl        = "http://" hostport [ "/" hpath [ "?" search ]]
 * hpath          = hsegment *[ "/" hsegment ]
 * hsegment       = *[ uchar | ";" | ":" | "@" | "&" | "=" ]
 * search         = *[ uchar | ";" | ":" | "@" | "&" | "=" ]
 */
QString KBiffURL::searchPar( const QString & _parName ) const
{
  int n=0;
  // Get the search part of the URL, i.e. the stuff after "?"
  QString query_str(query());
  if (!query_str.isEmpty())
    query_str = query_str.remove(0,1);
  n= query_str.indexOf( QRegExp(QString("(&|^)")+_parName+"=[^;:@&=]") );
  if( n>=0 )
  {
      if( query_str[n]=='&' )
          ++n;
      int from = n+_parName.size()+1, 
          to   = query_str.indexOf(QRegExp("[;:@&=]"), n+_parName.size()+1);
      return query_str.mid(from).left(to-from);
  }
  else
      return QString::null;
}

void KBiffURL::setSearchPar( const QString & _parName, const QString & _newParVal )
{
    // Get the search part of the URL, i.e. the stuff after "?"
    QString query_str(query());

    if (!query_str.isEmpty())
        query_str = query_str.remove(0,1);
    query_str.remove( QRegExp(QString("(&|^)")+_parName+"(=[^;:@&=]*)?") );
    if( !query_str.isEmpty() )
    {
        if( query_str[0] =='&' )
            query_str.remove(0,1);
        query_str += "&";
    }
    query_str += _parName + "=" + _newParVal;
    setQuery( query_str );
}

QString KBiffURL::pass() const
{
  return KUrl::decode_string(KUrl::pass());
}
